@@ -65,7 +65,7 @@ namespace pagmo
  * \verbatim embed:rst:leading-asterisk
  * .. warning::
  *
- *    A moved-from pagmo::nlopt is destructible and assignable. Any other operation will result
+ *    A moved-from pagmo::sade is destructible and assignable. Any other operation will result
  *    in undefined behaviour.
  *
  * .. warning::
@@ -150,8 +150,9 @@ public:
                             + std::to_string(variant) + " was detected.");
         }
         if (variant_adptv < 1u || variant_adptv > 2u) {
-            pagmo_throw(std::invalid_argument, "The variant for self-adaptation mus be in [1,2], while a value of "
-                                                   + std::to_string(variant_adptv) + " was detected.");
+            pagmo_throw(std::invalid_argument,
+                        "The variant for self-adaptation must be in [1,2], while a value of "
+                            + std::to_string(variant_adptv) + " was detected.");
         }
     }
 
@@ -184,12 +185,14 @@ public:
         // We start by checking that the problem is suitable for this
         // particular algorithm.
         if (prob.get_nc() != 0u) {
-            pagmo_throw(std::invalid_argument, "Non linear constraints detected in " + prob.get_name() + " instance. "
-                                                   + get_name() + " cannot deal with them");
+            pagmo_throw(std::invalid_argument,
+                        "Non linear constraints detected in " + prob.get_name() + " instance. " + get_name()
+                            + " cannot deal with them");
         }
         if (prob_f_dimension != 1u) {
-            pagmo_throw(std::invalid_argument, "Multiple objectives detected in " + prob.get_name() + " instance. "
-                                                   + get_name() + " cannot deal with them");
+            pagmo_throw(std::invalid_argument,
+                        "Multiple objectives detected in " + prob.get_name() + " instance. " + get_name()
+                            + " cannot deal with them");
         }
         if (prob.is_stochastic()) {
             pagmo_throw(std::invalid_argument,
@@ -200,8 +203,9 @@ public:
             return pop;
         }
         if (pop.size() < 7u) {
-            pagmo_throw(std::invalid_argument, get_name() + " needs at least 7 individuals in the population, "
-                                                   + std::to_string(pop.size()) + " detected");
+            pagmo_throw(std::invalid_argument,
+                        get_name() + " needs at least 7 individuals in the population, " + std::to_string(pop.size())
+                            + " detected");
         }
         // ---------------------------------------------------------------------------------------------------------
 
@@ -664,8 +668,8 @@ public:
                     df = std::abs(pop.get_f()[worst_idx][0] - pop.get_f()[best_idx][0]);
                     // Every 50 lines print the column names
                     if (count % 50u == 1u) {
-                        print("\n", std::setw(7), "Gen:", std::setw(15), "Fevals:", std::setw(15), "Best:",
-                              std::setw(15), "F:", std::setw(15), "CR:", std::setw(15), "dx:", std::setw(15),
+                        print("\n", std::setw(7), "Gen:", std::setw(15), "Fevals:", std::setw(15),
+                              "Best:", std::setw(15), "F:", std::setw(15), "CR:", std::setw(15), "dx:", std::setw(15),
                               std::setw(15), "df:", '\n');
                     }
                     print(std::setw(7), gen, std::setw(15), prob.get_fevals() - fevals0, std::setw(15),
