@@ -233,14 +233,14 @@ public:
     {
         // Checks on the input vectors.
         if (x.size() != m_prob.get_nx()) {
-            pagmo_throw(std::invalid_argument,
-                        "Trying to add a decision vector of dimension: " + std::to_string(x.size())
-                            + ", while the problem's dimension is: " + std::to_string(m_prob.get_nx()));
+            pagmo_throw(std::invalid_argument, "Trying to add a decision vector of dimension: "
+                                                   + std::to_string(x.size()) + ", while the problem's dimension is: "
+                                                   + std::to_string(m_prob.get_nx()));
         }
         if (f.size() != m_prob.get_nf()) {
-            pagmo_throw(std::invalid_argument,
-                        "Trying to add a fitness of dimension: " + std::to_string(f.size())
-                            + ", while the problem's fitness has dimension: " + std::to_string(m_prob.get_nf()));
+            pagmo_throw(std::invalid_argument, "Trying to add a fitness of dimension: " + std::to_string(f.size())
+                                                   + ", while the problem's fitness has dimension: "
+                                                   + std::to_string(m_prob.get_nf()));
         }
 
         // Prepare quantities to be appended to the internal vectors.
@@ -272,7 +272,7 @@ public:
      */
     vector_double random_decision_vector() const
     {
-        return pagmo::random_decision_vector(m_prob.get_bounds(), m_e);
+        return pagmo::random_decision_vector(m_prob.get_bounds(), m_e, get_problem().get_nix());
     }
 
     /// Index of the best individual
@@ -473,19 +473,18 @@ public:
     void set_xf(size_type i, const vector_double &x, const vector_double &f)
     {
         if (i >= size()) {
-            pagmo_throw(std::invalid_argument,
-                        "Trying to access individual at position: " + std::to_string(i)
-                            + ", while population has size: " + std::to_string(size()));
+            pagmo_throw(std::invalid_argument, "Trying to access individual at position: " + std::to_string(i)
+                                                   + ", while population has size: " + std::to_string(size()));
         }
         if (f.size() != m_prob.get_nf()) {
-            pagmo_throw(std::invalid_argument,
-                        "Trying to set a fitness of dimension: " + std::to_string(f.size())
-                            + ", while the problem's fitness has dimension: " + std::to_string(m_prob.get_nf()));
+            pagmo_throw(std::invalid_argument, "Trying to set a fitness of dimension: " + std::to_string(f.size())
+                                                   + ", while the problem's fitness has dimension: "
+                                                   + std::to_string(m_prob.get_nf()));
         }
         if (x.size() != m_prob.get_nx()) {
-            pagmo_throw(std::invalid_argument,
-                        "Trying to set a decision vector of dimension: " + std::to_string(x.size())
-                            + ", while the problem's dimension is: " + std::to_string(m_prob.get_nx()));
+            pagmo_throw(std::invalid_argument, "Trying to set a decision vector of dimension: "
+                                                   + std::to_string(x.size()) + ", while the problem's dimension is: "
+                                                   + std::to_string(m_prob.get_nx()));
         }
 
         // Reserve space for the incoming vectors. If any of this throws,
